const router = require('express').Router()
const Address = require('../models/address')
const virifyToken = require('../middlewares/verify-token')
const axios = require('axios')

router.post('/address', virifyToken, async (req, res) => {
  try {
    let address = new Address()
    address.user = req.decoded._id
    address.country = req.body.country
    address.fullName = req.body.fullName
    address.streetAddress = req.body.streetAddress
    address.city = req.body.city
    address.state = req.body.state
    address.zipCode = req.body.zipCode
    address.phoneNumber = req.body.phoneNumber
    address.deliverInstructions = req.body.deliverInstructions
    address.securityCode = req.body.securityCode

    await address.save()
    res.json({
      success: true,
      message: 'Success added an address'
    })
  } catch (err) {
    res.status(500).json({
      success: false,
      message: err.message
    })
  }
})

router.get('/address', virifyToken, async (req, res) => {
  try {
    let addresses = await Address.find({ user: req.decoded._id })

    res.json({
      success: true,
      addresses
    })

  } catch (err) {
    res.status(500).json({
      success: false,
      message: err.message
    })
  }
})

router.get('/countries', async (req, res) => {
  try {
    let response = await axios.get('https://restcountries.eu/rest/v2/all')

    res.json(response.data)
  } catch (err) {
    res.status(500).json({
      success: false,
      message: err.message
    })
  }
})
module.exports = router